@@ -2,10 +2,11 @@
     Common routines for models in PyTorch.
 """
 
-__all__ = ['round_channels', 'Identity', 'Swish', 'HSigmoid', 'HSwish', 'get_activation_layer', 'SelectableDense',
-           'DenseBlock', 'ConvBlock1d', 'conv1x1', 'conv3x3', 'depthwise_conv3x3', 'ConvBlock', 'conv1x1_block',
-           'conv3x3_block', 'conv7x7_block', 'dwconv_block', 'dwconv3x3_block', 'dwconv5x5_block', 'dwsconv3x3_block',
-           'PreConvBlock', 'pre_conv1x1_block', 'pre_conv3x3_block', 'DeconvBlock', 'NormActivation',
+__all__ = ['round_channels', 'Identity', 'BreakBlock', 'Swish', 'HSigmoid', 'HSwish', 'get_activation_layer',
+           'SelectableDense', 'DenseBlock', 'ConvBlock1d', 'conv1x1', 'conv3x3', 'depthwise_conv3x3', 'ConvBlock',
+           'conv1x1_block', 'conv3x3_block', 'conv5x5_block', 'conv7x7_block', 'dwconv_block', 'dwconv3x3_block',
+           'dwconv5x5_block', 'dwsconv3x3_block', 'PreConvBlock', 'pre_conv1x1_block', 'pre_conv3x3_block',
+           'AsymConvBlock', 'asym_conv3x3_block', 'DeconvBlock', 'deconv3x3_block', 'NormActivation',
            'InterpolationBlock', 'ChannelShuffle', 'ChannelShuffle2', 'SEBlock', 'SABlock', 'SAConvBlock',
            'saconv3x3_block', 'DucBlock', 'IBN', 'DualPathSequential', 'Concurrent', 'SequentialConcurrent',
            'ParametricSequential', 'ParametricConcurrent', 'Hourglass', 'SesquialteralHourglass',
@@ -52,6 +53,23 @@ class Identity(nn.Module):
     def forward(self, x):
         return x
 
+    def __repr__(self):
+        return '{name}()'.format(name=self.__class__.__name__)
+
+
+class BreakBlock(nn.Module):
+    """
+    Break coonnection block for hourglass.
+    """
+    def __init__(self):
+        super(BreakBlock, self).__init__()
+
+    def forward(self, x):
+        return None
+
+    def __repr__(self):
+        return '{name}()'.format(name=self.__class__.__name__)
+
 
 class Swish(nn.Module):
     """
@@ -342,6 +360,8 @@ def conv3x3(in_channels,
         Strides of the convolution.
     padding : int or tuple/list of 2 int, default 1
         Padding value for convolution layer.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for convolution layer.
     groups : int, default 1
         Number of groups.
     bias : bool, default False
@@ -359,7 +379,10 @@ def conv3x3(in_channels,
 
 
 def depthwise_conv3x3(channels,
-                      stride):
+                      stride=1,
+                      padding=1,
+                      dilation=1,
+                      bias=False):
     """
     Depthwise convolution 3x3 layer.
 
@@ -367,17 +390,24 @@ def depthwise_conv3x3(channels,
     ----------
     channels : int
         Number of input/output channels.
-    strides : int or tuple/list of 2 int
+    strides : int or tuple/list of 2 int, default 1
         Strides of the convolution.
+    padding : int or tuple/list of 2 int, default 1
+        Padding value for convolution layer.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for convolution layer.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
     """
     return nn.Conv2d(
         in_channels=channels,
         out_channels=channels,
         kernel_size=3,
         stride=stride,
-        padding=1,
+        padding=padding,
+        dilation=dilation,
         groups=channels,
-        bias=False)
+        bias=bias)
 
 
 class ConvBlock(nn.Module):
@@ -559,6 +589,7 @@ def conv5x5_block(in_channels,
                   dilation=1,
                   groups=1,
                   bias=False,
+                  use_bn=True,
                   bn_eps=1e-5,
                   activation=(lambda: nn.ReLU(inplace=True))):
     """
@@ -580,6 +611,8 @@ def conv5x5_block(in_channels,
         Number of groups.
     bias : bool, default False
         Whether the layer uses a bias vector.
+    use_bn : bool, default True
+        Whether to use BatchNorm layer.
     bn_eps : float, default 1e-5
         Small float added to variance in Batch norm.
     activation : function or str or None, default nn.ReLU(inplace=True)
@@ -594,6 +627,7 @@ def conv5x5_block(in_channels,
         dilation=dilation,
         groups=groups,
         bias=bias,
+        use_bn=use_bn,
         bn_eps=bn_eps,
         activation=activation)
 
@@ -602,8 +636,11 @@ def conv7x7_block(in_channels,
                   out_channels,
                   stride=1,
                   padding=3,
+                  dilation=1,
+                  groups=1,
                   bias=False,
                   use_bn=True,
+                  bn_eps=1e-5,
                   activation=(lambda: nn.ReLU(inplace=True))):
     """
     7x7 version of the standard convolution block.
@@ -618,10 +655,16 @@ def conv7x7_block(in_channels,
         Strides of the convolution.
     padding : int or tuple/list of 2 int, default 3
         Padding value for convolution layer.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for convolution layer.
+    groups : int, default 1
+        Number of groups.
     bias : bool, default False
         Whether the layer uses a bias vector.
     use_bn : bool, default True
         Whether to use BatchNorm layer.
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
     activation : function or str or None, default nn.ReLU(inplace=True)
         Activation function or name of activation function.
     """
@@ -631,8 +674,11 @@ def conv7x7_block(in_channels,
         kernel_size=7,
         stride=stride,
         padding=padding,
+        dilation=dilation,
+        groups=groups,
         bias=bias,
         use_bn=use_bn,
+        bn_eps=bn_eps,
         activation=activation)
 
 
@@ -1043,6 +1089,113 @@ def pre_conv3x3_block(in_channels,
         activate=activate)
 
 
+class AsymConvBlock(nn.Module):
+    """
+    Asymmetric separable convolution block.
+
+    Parameters:
+    ----------
+    channels : int
+        Number of input/output channels.
+    kernel_size : int
+        Convolution window size.
+    padding : int
+        Padding value for convolution layer.
+    dilation : int, default 1
+        Dilation value for convolution layer.
+    groups : int, default 1
+        Number of groups.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    lw_use_bn : bool, default True
+        Whether to use BatchNorm layer (leftwise convolution block).
+    rw_use_bn : bool, default True
+        Whether to use BatchNorm layer (rightwise convolution block).
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
+    lw_activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function after the leftwise convolution block.
+    rw_activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function after the rightwise convolution block.
+    """
+    def __init__(self,
+                 channels,
+                 kernel_size,
+                 padding,
+                 dilation=1,
+                 groups=1,
+                 bias=False,
+                 lw_use_bn=True,
+                 rw_use_bn=True,
+                 bn_eps=1e-5,
+                 lw_activation=(lambda: nn.ReLU(inplace=True)),
+                 rw_activation=(lambda: nn.ReLU(inplace=True))):
+        super(AsymConvBlock, self).__init__()
+        self.lw_conv = ConvBlock(
+            in_channels=channels,
+            out_channels=channels,
+            kernel_size=(kernel_size, 1),
+            stride=1,
+            padding=(padding, 0),
+            dilation=(dilation, 1),
+            groups=groups,
+            bias=bias,
+            use_bn=lw_use_bn,
+            bn_eps=bn_eps,
+            activation=lw_activation)
+        self.rw_conv = ConvBlock(
+            in_channels=channels,
+            out_channels=channels,
+            kernel_size=(1, kernel_size),
+            stride=1,
+            padding=(0, padding),
+            dilation=(1, dilation),
+            groups=groups,
+            bias=bias,
+            use_bn=rw_use_bn,
+            bn_eps=bn_eps,
+            activation=rw_activation)
+
+    def forward(self, x):
+        x = self.lw_conv(x)
+        x = self.rw_conv(x)
+        return x
+
+
+def asym_conv3x3_block(padding=1,
+                       **kwargs):
+    """
+    3x3 asymmetric separable convolution block.
+
+    Parameters:
+    ----------
+    channels : int
+        Number of input/output channels.
+    padding : int, default 1
+        Padding value for convolution layer.
+    dilation : int, default 1
+        Dilation value for convolution layer.
+    groups : int, default 1
+        Number of groups.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    lw_use_bn : bool, default True
+        Whether to use BatchNorm layer (leftwise convolution block).
+    rw_use_bn : bool, default True
+        Whether to use BatchNorm layer (rightwise convolution block).
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
+    lw_activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function after the leftwise convolution block.
+    rw_activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function after the rightwise convolution block.
+    """
+    return AsymConvBlock(
+        kernel_size=3,
+        padding=padding,
+        **kwargs)
+
+
 class DeconvBlock(nn.Module):
     """
     Deconvolution block with batch normalization and activation.
@@ -1125,6 +1278,46 @@ class DeconvBlock(nn.Module):
         return x
 
 
+def deconv3x3_block(padding=1,
+                    out_padding=1,
+                    **kwargs):
+    """
+    3x3 version of the deconvolution block with batch normalization and activation.
+
+    Parameters:
+    ----------
+    in_channels : int
+        Number of input channels.
+    out_channels : int
+        Number of output channels.
+    stride : int or tuple/list of 2 int
+        Strides of the deconvolution.
+    padding : int or tuple/list of 2 int, default 1
+        Padding value for deconvolution layer.
+    ext_padding : tuple/list of 4 int, default None
+        Extra padding value for deconvolution layer.
+    out_padding : int or tuple/list of 2 int, default 1
+        Output padding value for deconvolution layer.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for deconvolution layer.
+    groups : int, default 1
+        Number of groups.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    use_bn : bool, default True
+        Whether to use BatchNorm layer.
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
+    activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function or name of activation function.
+    """
+    return DeconvBlock(
+        kernel_size=3,
+        padding=padding,
+        out_padding=out_padding,
+        **kwargs)
+
+
 class NormActivation(nn.Module):
     """
     Activation block with preliminary batch normalization. It's used by itself as the final block in PreResNet.
@@ -1135,15 +1328,18 @@ class NormActivation(nn.Module):
         Number of input channels.
     bn_eps : float, default 1e-5
         Small float added to variance in Batch norm.
+    activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function or name of activation function.
     """
     def __init__(self,
                  in_channels,
-                 bn_eps=1e-5):
+                 bn_eps=1e-5,
+                 activation=(lambda: nn.ReLU(inplace=True))):
         super(NormActivation, self).__init__()
         self.bn = nn.BatchNorm2d(
             num_features=in_channels,
             eps=bn_eps)
-        self.activ = nn.ReLU(inplace=True)
+        self.activ = get_activation_layer(activation)
 
     def forward(self, x):
         x = self.bn(x)
@@ -1274,6 +1470,12 @@ class ChannelShuffle(nn.Module):
     def forward(self, x):
         return channel_shuffle(x, self.groups)
 
+    def __repr__(self):
+        s = "{name}(groups={groups})"
+        return s.format(
+            name=self.__class__.__name__,
+            groups=self.groups)
+
 
 def channel_shuffle2(x,
                      groups):
@@ -1720,22 +1922,33 @@ class Concurrent(nn.Sequential):
         The axis on which to concatenate the outputs.
     stack : bool, default False
         Whether to concatenate tensors along a new dimension.
+    merge_type : str, default None
+        Type of branch merging.
     """
     def __init__(self,
                  axis=1,
-                 stack=False):
+                 stack=False,
+                 merge_type=None):
         super(Concurrent, self).__init__()
+        assert (merge_type in ["cat", "stack", "sum"])
         self.axis = axis
-        self.stack = stack
+        if merge_type is not None:
+            self.merge_type = merge_type
+        else:
+            self.merge_type = "stack" if stack else "cat"
 
     def forward(self, x):
         out = []
         for module in self._modules.values():
             out.append(module(x))
-        if self.stack:
+        if self.merge_type == "stack":
             out = torch.stack(tuple(out), dim=self.axis)
-        else:
+        elif self.merge_type == "cat":
             out = torch.cat(tuple(out), dim=self.axis)
+        elif self.merge_type == "sum":
+            out = torch.stack(tuple(out), dim=self.axis).sum(self.axis)
+        else:
+            raise NotImplementedError()
         return out
 
 
@@ -1811,7 +2024,7 @@ class ParametricConcurrent(nn.Sequential):
 
 class Hourglass(nn.Module):
     """
-    A hourglass block.
+    A hourglass module.
 
     Parameters:
     ----------
@@ -1834,7 +2047,7 @@ class Hourglass(nn.Module):
                  return_first_skip=False):
         super(Hourglass, self).__init__()
         self.depth = len(down_seq)
-        assert (merge_type in ["add"])
+        assert (merge_type in ["cat", "add"])
         assert (len(up_seq) == self.depth)
         assert (len(skip_seq) in (self.depth, self.depth + 1))
         self.merge_type = merge_type
@@ -1845,6 +2058,14 @@ class Hourglass(nn.Module):
         self.up_seq = up_seq
         self.skip_seq = skip_seq
 
+    def _merge(self, x, y):
+        if y is not None:
+            if self.merge_type == "cat":
+                x = torch.cat((x, y), dim=1)
+            elif self.merge_type == "add":
+                x = x + y
+        return x
+
     def forward(self, x, **kwargs):
         y = None
         down_outs = [x]
@@ -1856,8 +2077,7 @@ class Hourglass(nn.Module):
                 y = down_outs[self.depth - i]
                 skip_module = self.skip_seq[self.depth - i]
                 y = skip_module(y)
-                if (y is not None) and (self.merge_type == "add"):
-                    x = x + y
+                x = self._merge(x, y)
             if i != len(down_outs) - 1:
                 if (i == 0) and self.extra_skip:
                     skip_module = self.skip_seq[self.depth]
