@@ -1,5 +1,5 @@
 """
-    InceptionV3, implemented in PyTorch.
+    InceptionV3 for ImageNet-1K, implemented in PyTorch.
     Original paper: 'Rethinking the Inception Architecture for Computer Vision,'
     https://arxiv.org/abs/1512.00567.
 """
@@ -579,13 +579,13 @@ class InceptionV3(nn.Module):
                 in_channels = out_channels
             self.features.add_module("stage{}".format(i + 1), stage)
 
-        self.features.add_module('final_pool', nn.AvgPool2d(
+        self.features.add_module("final_pool", nn.AvgPool2d(
             kernel_size=8,
             stride=1))
 
         self.output = nn.Sequential()
-        self.output.add_module('dropout', nn.Dropout(p=dropout_rate))
-        self.output.add_module('fc', nn.Linear(
+        self.output.add_module("dropout", nn.Dropout(p=dropout_rate))
+        self.output.add_module("fc", nn.Linear(
             in_features=in_channels,
             out_features=num_classes))
 
@@ -607,7 +607,7 @@ class InceptionV3(nn.Module):
 
 def get_inceptionv3(model_name=None,
                     pretrained=False,
-                    root=os.path.join('~', '.torch', 'models'),
+                    root=os.path.join("~", ".torch", "models"),
                     **kwargs):
     """
     Create InceptionV3 model with specific parameters.
@@ -672,7 +672,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -690,7 +689,7 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != inceptionv3 or weight_count == 23834568)
 
-        x = Variable(torch.randn(1, 3, 299, 299))
+        x = torch.randn(1, 3, 299, 299)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
